pub struct CompileTimePragmaEnvironment { /* private fields */ }Expand description
Explicit compile-time pragma environment that can answer file-position queries and expose immutable snapshots.
Implementations
Sourceimpl CompileTimePragmaEnvironment
impl CompileTimePragmaEnvironment
Sourcepub fn query_at(&self, offset: usize) -> PragmaStateQuery
pub fn query_at(&self, offset: usize) -> PragmaStateQuery
Return a position query object with immutable state snapshot.
Sourcepub fn snapshot_at(&self, offset: usize) -> PragmaSnapshot
pub fn snapshot_at(&self, offset: usize) -> PragmaSnapshot
Return the immutable snapshot active at the given byte offset.
Sourcepub fn as_map(&self) -> &[(Range<usize>, PragmaSnapshot)]
pub fn as_map(&self) -> &[(Range<usize>, PragmaSnapshot)]
Access the underlying range map for advanced consumers.